sum.fp <-
function(null.column, cutoff) {
	return(sum(null.column>cutoff))
}

